@@ -28,10 +28,9 @@ except ImportError:  # pragma: no cover
 import logging
 
 # Python classes for policy representation
-from . import policyrep
 from .policyrep import SELinuxPolicy, BoundsRuletype, ConstraintRuletype, DefaultRuletype, \
-                       DefaultRangeValue, DefaultValue, FSUseRuletype, HandleUnknown, MLSRuletype, \
-                       NodeconIPVersion, PolicyTarget, PortconProtocol, RBACRuletype, TERuletype
+    DefaultRangeValue, DefaultValue, FSUseRuletype, HandleUnknown, IbpkeyconRange, MLSRuletype, \
+    NodeconIPVersion, PolicyTarget, PortconProtocol, RBACRuletype, TERuletype
 
 # Exceptions
 from . import exception
@@ -63,6 +62,8 @@ from .defaultquery import DefaultQuery
 # In-policy Context Queries
 from .fsusequery import FSUseQuery
 from .genfsconquery import GenfsconQuery
+from .ibendportconquery import IbendportconQuery
+from .ibpkeyconquery import IbpkeyconQuery
 from .initsidquery import InitialSIDQuery
 from .netifconquery import NetifconQuery
 from .nodeconquery import NodeconQuery
