@@ -32,6 +32,8 @@ from .defaultquery import DefaultQueryTab
 from .dta import DomainTransitionAnalysisTab
 from .fsusequery import FSUseQueryTab
 from .genfsconquery import GenfsconQueryTab
+from .ibendportconquery import IbendportconQueryTab
+from .ibpkeyconquery import IbpkeyconQueryTab
 from .infoflow import InfoFlowAnalysisTab
 from .initsidquery import InitialSIDQueryTab
 from .mlsrulequery import MLSRuleQueryTab
@@ -59,6 +61,8 @@ tab_map = {"BoolQueryTab": BoolQueryTab,
            "DomainTransitionAnalysisTab": DomainTransitionAnalysisTab,
            "FSUseQueryTab": FSUseQueryTab,
            "GenfsconQueryTab": GenfsconQueryTab,
+           "IbendportconQueryTab": IbendportconQueryTab,
+           "IbpkeyconQueryTab": IbpkeyconQueryTab,
            "InfoFlowAnalysisTab": InfoFlowAnalysisTab,
            "InitialSIDQueryTab": InitialSIDQueryTab,
            "MLSRuleQueryTab": MLSRuleQueryTab,
@@ -109,10 +113,12 @@ class ChooseAnalysis(SEToolsWidget, QDialog):
                     "TE Rules": TERuleQueryTab}
         labeling_map = {"Fs_use_* Statements": FSUseQueryTab,
                         "Genfscon Statements": GenfsconQueryTab,
+                        "Infiniband Endport Contexts": IbendportconQueryTab,
+                        "Infiniband Partition Key Contexts": IbpkeyconQueryTab,
                         "Initial SID Statements": InitialSIDQueryTab,
-                        "Netifcon Statements": NetifconQueryTab,
-                        "Nodecon Statements": NodeconQueryTab,
-                        "Portcon Statements": PortconQueryTab}
+                        "Network Interface Contexts": NetifconQueryTab,
+                        "Network Node Contexts": NodeconQueryTab,
+                        "Network Port Contexts": PortconQueryTab}
         general_choices = {"Summary": SummaryTab}
         other_choices = {"Bounds": BoundsQueryTab,
                          "Defaults": DefaultQueryTab}
