@@ -1,5 +1,5 @@
 # Copyright 2015-2016, Tresys Technology, LLC
-# Copyright 2016, Chris PeBenito <pebenito@ieee.org>
+# Copyright 2016, 2019, Chris PeBenito <pebenito@ieee.org>
 #
 # This file is part of SETools.
 #
@@ -18,11 +18,9 @@
 # <http://www.gnu.org/licenses/>.
 #
 import os
-import sys
-import stat
+import shutil
 import logging
 import json
-from errno import ENOENT
 from contextlib import suppress
 
 import pkg_resources
@@ -33,11 +31,16 @@ from setools import __version__, PermissionMap, SELinuxPolicy
 from ..widget import SEToolsWidget
 from ..logtosignal import LogHandlerToSignal
 from .chooseanalysis import ChooseAnalysis, tab_map
+from .config import ApolConfig
 from .exception import TabFieldError
 from .permmapedit import PermissionMapEditor
 from .summary import SummaryTab
 
 
+BIN_SEARCH_PATHS = ("/usr/local/bin:/usr/bin:/bin")
+POSSIBLE_ASSISTANT = ("assistant", "assistant-qt5")
+
+
 class ApolMainWindow(SEToolsWidget, QMainWindow):
 
     def __init__(self, filename):
@@ -45,6 +48,7 @@ class ApolMainWindow(SEToolsWidget, QMainWindow):
         self.log = logging.getLogger(__name__)
         self._permmap = None
         self._policy = None
+        self.config = ApolConfig()
         self.setupUi()
 
         self.load_permmap()
@@ -115,6 +119,7 @@ class ApolMainWindow(SEToolsWidget, QMainWindow):
         self.save_permmap_action.triggered.connect(self.save_permmap)
         self.about_apol_action.triggered.connect(self.about_apol)
         self.apol_help_action.triggered.connect(self.apol_help)
+        self.help_process.errorOccurred.connect(self.help_failed)
 
         self.show()
 
@@ -169,7 +174,7 @@ class ApolMainWindow(SEToolsWidget, QMainWindow):
         if self.AnalysisTabs.count() > 0:
             reply = QMessageBox.question(
                 self, "Continue?",
-                "Loading a policy will close all existing analyses.  Continue?",
+                "Closing a policy will close all existing analyses.  Continue?",
                 QMessageBox.Yes | QMessageBox.No)
 
             if reply == QMessageBox.No:
@@ -635,7 +640,7 @@ class ApolMainWindow(SEToolsWidget, QMainWindow):
                           "<a href=\"https://github.com/SELinuxProject/setools/wiki\">"
                           "SETools</a>.<p>"
                           "Copyright (C) 2015-2016, Tresys Technology<p>"
-                          "Copyright (C) 2016, Chris PeBenito <pebenito@ieee.org>".
+                          "Copyright (C) 2016-2019, Chris PeBenito <pebenito@ieee.org>".
                           format(__version__))
 
     def apol_help(self):
@@ -647,11 +652,52 @@ class ApolMainWindow(SEToolsWidget, QMainWindow):
         helpfile = "{0}/setoolsgui/apol/apol.qhc".format(distro.location)
 
         self.log.debug("Starting assistant with help file {0}".format(helpfile))
-        self.help_process.start("assistant",
+        self.help_process.start(self.config.assistant,
                                 ["-collectionFile", helpfile, "-showUrl",
                                  "qthelp://com.github.selinuxproject.setools/doc/index.html",
                                  "-show", "contents", "-enableRemoteControl"])
 
+    @pyqtSlot(QProcess.ProcessError)
+    def help_failed(self, error):
+        """Starting assistant failed."""
+        if error != QProcess.FailedToStart:
+            return
+
+        self.log.error("Failed to start Qt assistant {}.".format(self.config.assistant))
+        self._find_assistant()
+
+    def _find_assistant(self):
+        """Try to find qt assistant in a few standard locations."""
+        for name in POSSIBLE_ASSISTANT:
+            self.log.debug("Trying assistant {}".format(name))
+            filename = shutil.which(name, mode=os.F_OK | os.X_OK, path=BIN_SEARCH_PATHS)
+            if filename:
+                self.log.debug("Assistant {} is available and executable.".format(filename))
+                break
+        else:
+            reply = QMessageBox.question(
+                self, "Qt Assistant Package Installed?",
+                "Failed to start QT Assistant program {}. "
+                "This is typically in the assistant or qt5-assistant package. "
+                "Choose location of Qt Assistant executable?".format(
+                    self.config.assistant),
+                QMessageBox.Yes | QMessageBox.No)
+
+            if reply == QMessageBox.No:
+                return
+
+            filename = QFileDialog.getOpenFileName(self, "Location of qt-assistant executable",
+                                                   "/usr/bin",
+                                                   "All Files (*)")[0]
+
+            self.log.debug("User chose assistant {}.".format(filename))
+
+        if filename:
+            self.log.debug("Updating config with assistant {}".format(filename))
+            self.config.assistant = filename
+            self.config.save()
+            self.apol_help()
+
     @pyqtSlot(str)
     def set_help(self, location):
         """Set the help window to the specified document."""
