@@ -281,7 +281,7 @@ class NodeconQueryTab(AnalysisTab):
         self.thread.start()
 
     def update_complete(self, count):
-        self.log.info("{0} nodecon statment(s) found.".format(count))
+        self.log.info("{0} nodecon statement(s) found.".format(count))
 
         # update sizes/location of result displays
         if not self.busy.wasCanceled():
